You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ponymail.apache.org by se...@apache.org on 2018/05/25 22:27:21 UTC

[incubator-ponymail] branch master updated: Better name: y => goodies

This is an automated email from the ASF dual-hosted git repository.

sebb pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-ponymail.git


The following commit(s) were added to refs/heads/master by this push:
     new 2b8b42d  Better name: y => goodies
2b8b42d is described below

commit 2b8b42d5d017a8978604205d5114e54ae811f96f
Author: Sebb <se...@apache.org>
AuthorDate: Fri May 25 23:27:17 2018 +0100

    Better name: y => goodies
---
 tools/import-mbox.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/tools/import-mbox.py b/tools/import-mbox.py
index 1ca9d4a..c147721 100755
--- a/tools/import-mbox.py
+++ b/tools/import-mbox.py
@@ -44,7 +44,7 @@ except ImportError as err:
 # must be done after import check above
 import archiver
     
-y = 0
+goodies = 0
 baddies = 0
 duplicates={} # detect if mid is re-used this run
 block = Lock()
@@ -146,7 +146,7 @@ class SlurpThread(Thread):
         print("%s: %s" % (self.name, message))
 
     def run(self):
         global block, y, es, lists, baddies, resendTo, timeout, dedupped, dedup
         self.name = Thread.getName(self)
         ja = []
         jas = []
@@ -356,7 +356,7 @@ class SlurpThread(Thread):
                 self.printid("Parsed %s/%s: %u records (failed: %u) from %s" % (ml, mboxfile, count, bad, tmpname))
                 os.unlink(tmpname)
                 
-            y += count
+            goodies += count
             baddies += bad
             if len(ja) > 0:
                 bulk = BulkThread(self.name, ja, es, 'mbox')
@@ -683,6 +683,6 @@ if args.dups:
             for msg in duplicates[mid]:
                 print(msg)
 
-print("All done! %u records inserted/updated after %u seconds. %u records were bad and ignored" % (y, int(time.time() - start), baddies))
+print("All done! %u records inserted/updated after %u seconds. %u records were bad and ignored" % (goodies, int(time.time() - start), baddies))
 if dedupped > 0:
     print("%u records were not inserted due to deduplication" % dedupped)
@@ -146,7 +146,7 @@ class SlurpThread(Thread):
 
     def run(self):
-        global block, y, es, lists, baddies, resendTo, timeout, dedupped, dedup
+        global block, goodies, es, lists, baddies, resendTo, timeout, dedupped, dedup
         self.name = Thread.getName(self)
         ja = []

-- 
To stop receiving notification emails like this one, please contact
sebb@apache.org.